@@ -52,14 +52,13 @@ sits_cluster_dendro <- function(samples = NULL,
                                 k = NULL,
                                 palette = "RdYlGn",
                                 .plot = TRUE, ...) {
-
-    # verify if data is OK
-    .sits_tibble_test(samples)
-
+    # needs package dtwclust
     .check_require_packages("dtwclust")
+    # verify if data is OK
+    .check_samples_train(samples)
 
     # bands in sits are uppercase
-    bands <- .sits_tibble_bands_check(samples, bands)
+    bands <- .tibble_bands_check(samples, bands)
 
     # calculate the dendrogram object
     message("calculating dendrogram...")
@@ -98,7 +97,7 @@ sits_cluster_dendro <- function(samples = NULL,
     # plot the dendrogram
     message("Plotting dendrogram...")
     if (.plot) {
-        .sits_plot_dendrogram(
+        .plot_dendrogram(
             data = samples,
             cluster = cluster,
             cutree_height = best_cut["height"],
@@ -133,11 +132,7 @@ sits_cluster_frequency <- function(samples) {
     .check_set_caller("sits_cluster_frequency")
 
     # is the input data the result of a cluster function?
-    .check_chr_contains(
-        names(samples),
-        contains = "cluster",
-        msg = "missing cluster column"
-    )
+    .check_samples_cluster(samples)
 
     # compute frequency table (matrix)
     result <- table(samples$label, samples$cluster)
@@ -179,11 +174,7 @@ sits_cluster_clean <- function(samples) {
     .check_set_caller("sits_cluster_clean")
 
     # is the input data the result of a cluster function?
-    .check_chr_contains(
-        names(samples),
-        contains = "cluster",
-        msg = "input data does not contain cluster column"
-    )
+    .check_samples_cluster(samples)
 
     # compute frequency table (matrix)
     result <- table(samples$label, samples$cluster)
@@ -212,6 +203,7 @@ sits_cluster_clean <- function(samples) {
 #' @title Cluster validity indices
 #' @name .sits_cluster_validity
 #' @keywords internal
+#' @noRd
 #' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
 #'
 #' @description Compute different cluster validity indices. This function needs
@@ -237,11 +229,7 @@ sits_cluster_clean <- function(samples) {
     .check_require_packages("dtwclust")
 
     # is the input data the result of a cluster function?
-    .check_chr_contains(
-        names(samples),
-        contains = "cluster",
-        msg = "input data does not have cluster column"
-    )
+    .check_samples_cluster(samples)
 
     # compute CVIs and return
     result <- dtwclust::cvi(
@@ -256,6 +244,7 @@ sits_cluster_clean <- function(samples) {
 #' @title Compute a dendrogram using hierarchical clustering
 #' @name .sits_cluster_dendrogram
 #' @keywords internal
+#' @noRd
 #' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
@@ -311,6 +300,7 @@ sits_cluster_clean <- function(samples) {
 #' @title Compute validity indexes to a range of cut height
 #' @name .sits_cluster_dendro_bestcut
 #' @keywords internal
+#' @noRd
 #' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
 #'
 #' @description Reads a dendrogram object and its corresponding sits tibble and
