@@ -1,10 +1,10 @@
 test_that("All", {
-    reproj <- .sits_proj_from_latlong(-10, -20, crs = 4326)
+    reproj <- .proj_from_latlong(-10, -20, crs = 4326)
 
     expect_equal(as.numeric(reproj[1, 1]), -10)
     expect_equal(as.numeric(reproj[1, 2]), -20)
 
-    reproj <- .sits_proj_to_latlong(-10, -20, 4326)
+    reproj <- .proj_to_latlong(-10, -20, 4326)
 
     expect_equal(as.numeric(reproj[1, 1]), -10)
     expect_equal(as.numeric(reproj[1, 2]), -20)
@@ -15,7 +15,7 @@ test_that("Time Series Dates", {
 })
 test_that("Timeline date", {
     timeline <- sits_timeline(cerrado_2classes)
-    expect_true(sits:::.sits_timeline_valid_date(
+    expect_true(.timeline_valid_date(
         as.Date("2000-09-12"),
         timeline
     ))
