@@ -11,7 +11,7 @@ test_that("View", {
         source = "BDC",
         collection = "MOD13Q1-6",
         data_dir = data_dir,
-        parse_info = c("X1", "X2", "tile", "band", "date")
+        parse_info = c("X1", "tile", "band", "date")
     )
 
     timeline <- sits_timeline(modis_cube)
@@ -25,10 +25,17 @@ test_that("View", {
     expect_true("leaflet" %in% class(v2))
     expect_true(grepl("EPSG3857", v2$x$options$crs$crsClass))
 
-    samples_ndvi <- sits_select(samples_modis_4bands,
-        bands = c("NDVI")
+    # plot the data cube RGB
+    vrgb <- sits_view(modis_cube,
+                    red = "NDVI",
+                    green = "NDVI",
+                    blue = "NDVI",
+                    dates = timeline[[1]]
     )
-    rf_model <- sits_train(samples_ndvi, sits_rfor())
+    expect_true("leaflet" %in% class(vrgb))
+    expect_true(grepl("EPSG3857", vrgb$x$options$crs$crsClass))
+
+    rf_model <- sits_train(samples_modis_ndvi, sits_rfor())
 
     modis_probs <- sits_classify(
         data = modis_cube,
@@ -64,3 +71,16 @@ test_that("View", {
     expect_true(all(file.remove(unlist(modis_probs$file_info[[1]]$path))))
     expect_true(all(file.remove(unlist(modis_label$file_info[[1]]$path))))
 })
+test_that("View SOM map", {
+    set.seed(2903)
+    som_map <- sits_som_map(
+        samples_modis_ndvi,
+        grid_xdim = 4,
+        grid_ydim = 4
+    )
+    v <- suppressMessages(sits_view(som_map, label = "Forest",
+                                    prob_min = 0))
+
+    expect_true(grepl("EPSG3857", v$x$options$crs$crsClass))
+    expect_equal(v$x$calls[[1]]$method, "addProviderTiles")
+})
